@@ -1,15 +1,5 @@
-use serde_json::Value;
-use std::fs;
-use std::io::{self, BufRead, BufReader};
-
-use crate::config::Config;
-use crate::util;
-use crate::CliResult;
-use serde::Deserialize;
-
-static USAGE: &str = "
-Converts a newline-delimited JSON file (.ndjson or .jsonl, typically) into
-a CSV file.
+static USAGE: &str = r#"
+Convert newline-delimited JSON (JSONL/NDJSON) to CSV.
 
 The command tries to do its best but since it is not possible to
 straightforwardly convert JSON lines to CSV, the process might lose some complex
@@ -18,21 +8,38 @@ fields from the input.
 Also, it will fail if the JSON documents are not consistent with one another,
 as the first JSON line will be use to infer the headers of the CSV output.
 
+For examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_jsonl.rs.
+
 Usage:
     qsv jsonl [options] [<input>]
     qsv jsonl --help
 
+jsonl options:
+    --ignore-errors        Skip malformed input lines.
+
 Common options:
     -h, --help             Display this message
     -o, --output <file>    Write output to <file> instead of stdout.
-";
+"#;
+
+use std::{
+    fs,
+    io::{self, BufRead, BufReader},
+};
+
+use serde::Deserialize;
+use serde_json::Value;
+
+use crate::{config::Config, util, CliResult};
 
 #[derive(Deserialize)]
 struct Args {
-    arg_input: Option<String>,
-    flag_output: Option<String>,
+    arg_input:          Option<String>,
+    flag_output:        Option<String>,
+    flag_ignore_errors: bool,
 }
 
+#[allow(clippy::needless_pass_by_value)]
 fn recurse_to_infer_headers(value: &Value, headers: &mut Vec<Vec<String>>, path: Vec<String>) {
     match value {
         Value::Object(map) => {
@@ -65,12 +72,12 @@ fn recurse_to_infer_headers(value: &Value, headers: &mut Vec<Vec<String>>, path:
     }
 }
 
-fn infer_headers(value: &Value) -> Option<Vec<Vec<String>>> {
+fn infer_headers(value: &Value) -> Vec<Vec<String>> {
     let mut headers: Vec<Vec<String>> = Vec::new();
 
     recurse_to_infer_headers(value, &mut headers, Vec::new());
 
-    Some(headers)
+    headers
 }
 
 fn get_value_at_path(value: &Value, path: &[String]) -> Option<Value> {
@@ -87,7 +94,7 @@ fn get_value_at_path(value: &Value, path: &[String]) -> Option<Value> {
         }
     }
 
-    Some(current.to_owned())
+    Some(current.clone())
 }
 
 fn json_line_to_csv_record(value: &Value, headers: &[Vec<String>]) -> csv::StringRecord {
@@ -134,18 +141,28 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut headers: Vec<Vec<String>> = Vec::new();
     let mut headers_emitted: bool = false;
 
-    for line in rdr.lines() {
-        let value: Value = serde_json::from_str(&line?).expect("Could not parse line as JSON!");
+    for (rowidx, line) in rdr.lines().enumerate() {
+        let value: Value = match serde_json::from_str(&line?) {
+            Ok(v) => v,
+            Err(e) => {
+                if args.flag_ignore_errors {
+                    continue;
+                }
+                let human_idx = rowidx + 1; // not zero based, for readability
+                return fail_clierror!(
+                    r#"Could not parse line {human_idx} as JSON!: {e}
+Use `--ignore-errors` option to skip malformed input lines.
+Use `tojsonl` command to convert _to_ jsonl instead of _from_ jsonl."#,
+                );
+            }
+        };
 
         if !headers_emitted {
-            if let Some(h) = infer_headers(&value) {
-                headers = h;
+            headers = infer_headers(&value);
 
-                let headers_formatted =
-                    headers.iter().map(|v| v.join(".")).collect::<Vec<String>>();
-                let headers_record = csv::StringRecord::from(headers_formatted);
-                wtr.write_record(&headers_record)?;
-            }
+            let headers_formatted = headers.iter().map(|v| v.join(".")).collect::<Vec<String>>();
+            let headers_record = csv::StringRecord::from(headers_formatted);
+            wtr.write_record(&headers_record)?;
 
             headers_emitted = true;
         }
