@@ -7,13 +7,13 @@ use std::{
     io::{BufReader, Read, Write},
     path::{Path, PathBuf},
     str,
+    sync::OnceLock,
 };
 
 use docopt::Docopt;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 use indicatif::{HumanCount, ProgressBar, ProgressDrawTarget, ProgressStyle};
 use log::log_enabled;
-use once_cell::sync::OnceCell;
 use reqwest::Client;
 use serde::de::DeserializeOwned;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
@@ -27,9 +27,9 @@ use crate::{
 };
 
 #[macro_export]
-macro_rules! regex_once_cell {
+macro_rules! regex_oncelock {
     ($re:literal $(,)?) => {{
-        static RE: once_cell::sync::OnceCell<regex::Regex> = once_cell::sync::OnceCell::new();
+        static RE: std::sync::OnceLock<regex::Regex> = std::sync::OnceLock::new();
         RE.get_or_init(|| regex::Regex::new($re).unwrap())
     }};
 }
@@ -37,7 +37,7 @@ macro_rules! regex_once_cell {
 // leave at least 20% of the available memory free
 const DEFAULT_FREEMEMORY_HEADROOM_PCT: u8 = 20;
 
-static ROW_COUNT: once_cell::sync::OnceCell<u64> = OnceCell::new();
+static ROW_COUNT: OnceLock<u64> = OnceLock::new();
 
 pub type ByteString = Vec<u8>;
 
@@ -946,7 +946,7 @@ pub fn safe_header_names(
     } else {
         unsafe_prefix
     };
-    let safename_regex = regex_once_cell!(r"[^A-Za-z0-9]");
+    let safename_regex = regex_oncelock!(r"[^A-Za-z0-9]");
     let mut changed_count = 0_u16;
     let mut name_vec: Vec<String> = Vec::with_capacity(headers.len());
 
@@ -1019,7 +1019,7 @@ pub fn is_safe_name(header_name: &str) -> bool {
     if first_character.is_ascii_digit() || first_character.is_ascii_whitespace() {
         return false;
     }
-    let safename_re = regex_once_cell!(r"^[\w\-\s]+$");
+    let safename_re = regex_oncelock!(r"^[\w\-\s]+$");
     safename_re.is_match(header_name)
 }
 
@@ -1435,3 +1435,67 @@ pub fn sniff_filetype_from_buffer(in_buffer: &bytes::Bytes) -> Result<String, Cl
         Ok("inode/x-empty".to_string())
     }
 }
+
+/// Process the input files and return a vector of paths to the input files
+///
+/// If the input is empty, try to copy stdin to a file named stdin in the passed temp directory
+/// If the input is empty and stdin is empty, return an error
+/// If it's not empty, check the input files if they exist
+///
+/// If the input is a directory, add all the files in the directory to the input
+/// If the input is a file, add the file to the input
+/// If the input are snappy compressed files, uncompress them before adding them to the input
+#[cfg(any(feature = "to", feature = "polars"))]
+pub fn process_input(
+    arg_input: Vec<PathBuf>,
+    tmpdir: &tempfile::TempDir,
+    empty_stdin_errmsg: &str,
+) -> Result<Vec<PathBuf>, CliError> {
+    let mut processed_input = Vec::with_capacity(arg_input.len());
+
+    if arg_input.is_empty() || arg_input[0] == PathBuf::from("-") {
+        // copy stdin to a file named stdin in a temp directory
+        let tmp_filename = tmpdir.path().join("stdin");
+        let mut tmp_file = std::fs::File::create(&tmp_filename)?;
+        let nbytes = std::io::copy(&mut std::io::stdin(), &mut tmp_file)?;
+        if nbytes == 0 {
+            return fail_clierror!("{empty_stdin_errmsg}");
+        }
+        tmp_file.flush()?;
+        processed_input.push(tmp_filename);
+    } else {
+        let mut work_input = Vec::with_capacity(arg_input.len());
+
+        // is the input a directory?
+        if arg_input.len() == 1 && arg_input[0].is_dir() {
+            // if so, add all the files in the directory to the input
+            let dir = std::fs::read_dir(arg_input[0].clone())?;
+            for entry in dir {
+                let entry = entry?;
+                let path = entry.path();
+                if path.is_file() {
+                    work_input.push(path);
+                }
+            }
+        } else {
+            work_input = arg_input;
+        }
+
+        // check the input files
+        for path in work_input {
+            // does the input file exist?
+            if !path.exists() {
+                return fail_clierror!("Input file '{}' does not exist", path.display());
+            }
+            // is the input file snappy compressed?
+            if path.extension().unwrap_or_default() == "sz" {
+                // if so, decompress the file
+                let decompressed_filepath = decompress_snappy_file(&path, tmpdir)?;
+                processed_input.push(PathBuf::from(decompressed_filepath));
+            } else {
+                processed_input.push(path.clone());
+            }
+        }
+    }
+    Ok(processed_input)
+}
